==> openshift-model-machineconfig-6.9.0-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ControllerCertificateFluent.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ControllerCertificateFluent<A extends ControllerCertificateFluent<A>> extends BaseFluent<A>{
  public ControllerCertificateFluent() {
  }
  
  public ControllerCertificateFluent(ControllerCertificate instance) {
    this.copyInstance(instance);
  }
  private String bundleFile;
  private String notAfter;
  private String notBefore;
  private String signer;
  private String subject;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ControllerCertificate instance) {
    instance = (instance != null ? instance : new ControllerCertificate());
  
    if (instance != null) {
        this.withBundleFile(instance.getBundleFile());
        this.withNotAfter(instance.getNotAfter());
        this.withNotBefore(instance.getNotBefore());
        this.withSigner(instance.getSigner());
        this.withSubject(instance.getSubject());
        this.withBundleFile(instance.getBundleFile());
        this.withNotAfter(instance.getNotAfter());
        this.withNotBefore(instance.getNotBefore());
        this.withSigner(instance.getSigner());
        this.withSubject(instance.getSubject());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getBundleFile() {
    return this.bundleFile;
  }
  
  public A withBundleFile(String bundleFile) {
    this.bundleFile=bundleFile; return (A) this;
  }
  
  public boolean hasBundleFile() {
    return this.bundleFile != null;
  }
  
  public String getNotAfter() {
    return this.notAfter;
  }
  
  public A withNotAfter(String notAfter) {
    this.notAfter=notAfter; return (A) this;
  }
  
  public boolean hasNotAfter() {
    return this.notAfter != null;
  }
  
  public String getNotBefore() {
    return this.notBefore;
  }
  
  public A withNotBefore(String notBefore) {
    this.notBefore=notBefore; return (A) this;
  }
  
  public boolean hasNotBefore() {
    return this.notBefore != null;
  }
  
  public String getSigner() {
    return this.signer;
  }
  
  public A withSigner(String signer) {
    this.signer=signer; return (A) this;
  }
  
  public boolean hasSigner() {
    return this.signer != null;
  }
  
  public String getSubject() {
    return this.subject;
  }
  
  public A withSubject(String subject) {
    this.subject=subject; return (A) this;
  }
  
  public boolean hasSubject() {
    return this.subject != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ControllerCertificateFluent that = (ControllerCertificateFluent) o;
    if (!java.util.Objects.equals(bundleFile, that.bundleFile)) return false;
  
    if (!java.util.Objects.equals(notAfter, that.notAfter)) return false;
  
    if (!java.util.Objects.equals(notBefore, that.notBefore)) return false;
  
    if (!java.util.Objects.equals(signer, that.signer)) return false;
  
    if (!java.util.Objects.equals(subject, that.subject)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(bundleFile,  notAfter,  notBefore,  signer,  subject,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (bundleFile != null) { sb.append("bundleFile:"); sb.append(bundleFile + ","); }
    if (notAfter != null) { sb.append("notAfter:"); sb.append(notAfter + ","); }
    if (notBefore != null) { sb.append("notBefore:"); sb.append(notBefore + ","); }
    if (signer != null) { sb.append("signer:"); sb.append(signer + ","); }
    if (subject != null) { sb.append("subject:"); sb.append(subject + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-machineconfig-6.9.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/ControllerCertificateFluent.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ControllerCertificateFluent<A extends ControllerCertificateFluent<A>> extends BaseFluent<A>{
  public ControllerCertificateFluent() {
  }
  
  public ControllerCertificateFluent(ControllerCertificate instance) {
    this.copyInstance(instance);
  }
  private String bundleFile;
  private String notAfter;
  private String notBefore;
  private String signer;
  private String subject;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ControllerCertificate instance) {
    instance = (instance != null ? instance : new ControllerCertificate());
    if (instance != null) {
          this.withBundleFile(instance.getBundleFile());
          this.withNotAfter(instance.getNotAfter());
          this.withNotBefore(instance.getNotBefore());
          this.withSigner(instance.getSigner());
          this.withSubject(instance.getSubject());
          this.withBundleFile(instance.getBundleFile());
          this.withNotAfter(instance.getNotAfter());
          this.withNotBefore(instance.getNotBefore());
          this.withSigner(instance.getSigner());
          this.withSubject(instance.getSubject());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getBundleFile() {
    return this.bundleFile;
  }
  
  public A withBundleFile(String bundleFile) {
    this.bundleFile = bundleFile;
    return (A) this;
  }
  
  public boolean hasBundleFile() {
    return this.bundleFile != null;
  }
  
  public String getNotAfter() {
    return this.notAfter;
  }
  
  public A withNotAfter(String notAfter) {
    this.notAfter = notAfter;
    return (A) this;
  }
  
  public boolean hasNotAfter() {
    return this.notAfter != null;
  }
  
  public String getNotBefore() {
    return this.notBefore;
  }
  
  public A withNotBefore(String notBefore) {
    this.notBefore = notBefore;
    return (A) this;
  }
  
  public boolean hasNotBefore() {
    return this.notBefore != null;
  }
  
  public String getSigner() {
    return this.signer;
  }
  
  public A withSigner(String signer) {
    this.signer = signer;
    return (A) this;
  }
  
  public boolean hasSigner() {
    return this.signer != null;
  }
  
  public String getSubject() {
    return this.subject;
  }
  
  public A withSubject(String subject) {
    this.subject = subject;
    return (A) this;
  }
  
  public boolean hasSubject() {
    return this.subject != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ControllerCertificateFluent that = (ControllerCertificateFluent) o;
    if (!java.util.Objects.equals(bundleFile, that.bundleFile)) return false;
    if (!java.util.Objects.equals(notAfter, that.notAfter)) return false;
    if (!java.util.Objects.equals(notBefore, that.notBefore)) return false;
    if (!java.util.Objects.equals(signer, that.signer)) return false;
    if (!java.util.Objects.equals(subject, that.subject)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(bundleFile,  notAfter,  notBefore,  signer,  subject,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (bundleFile != null) { sb.append("bundleFile:"); sb.append(bundleFile + ","); }
    if (notAfter != null) { sb.append("notAfter:"); sb.append(notAfter + ","); }
    if (notBefore != null) { sb.append("notBefore:"); sb.append(notBefore + ","); }
    if (signer != null) { sb.append("signer:"); sb.append(signer + ","); }
    if (subject != null) { sb.append("subject:"); sb.append(subject + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
